==> rad-0.8.1.tar.gz: lib/widgets_short_html.dart <==
// ignore_for_file: directives_ordering
// ignore_for_file: camel_case_types

/// HTML widgets with short aliases.
///
library widgets_short_tags;

import 'package:rad/src/widgets/html/abbreviation.dart';
import 'package:rad/src/widgets/html/anchor.dart';
import 'package:rad/src/widgets/html/article.dart';
import 'package:rad/src/widgets/html/blockquote.dart';
import 'package:rad/src/widgets/html/break_line.dart';
import 'package:rad/src/widgets/html/button.dart';
import 'package:rad/src/widgets/html/canvas.dart';
import 'package:rad/src/widgets/html/caption.dart';
import 'package:rad/src/widgets/html/code.dart';
import 'package:rad/src/widgets/html/division.dart';
import 'package:rad/src/widgets/html/fieldset.dart';
import 'package:rad/src/widgets/html/footer.dart';
import 'package:rad/src/widgets/html/form.dart';
import 'package:rad/src/widgets/html/header.dart';
import 'package:rad/src/widgets/html/headings.dart';
import 'package:rad/src/widgets/html/horizontal_rule.dart';
import 'package:rad/src/widgets/html/idiomatic.dart';
import 'package:rad/src/widgets/html/iframe.dart';
import 'package:rad/src/widgets/html/image.dart';
import 'package:rad/src/widgets/html/input.dart';
import 'package:rad/src/widgets/html/label.dart';
import 'package:rad/src/widgets/html/legend.dart';
import 'package:rad/src/widgets/html/list_item.dart';
import 'package:rad/src/widgets/html/menu.dart';
import 'package:rad/src/widgets/html/navigation.dart';
import 'package:rad/src/widgets/html/option.dart';
import 'package:rad/src/widgets/html/paragraph.dart';
import 'package:rad/src/widgets/html/progress.dart';
import 'package:rad/src/widgets/html/select.dart';
import 'package:rad/src/widgets/html/small.dart';
import 'package:rad/src/widgets/html/span.dart';
import 'package:rad/src/widgets/html/strike_through.dart';
import 'package:rad/src/widgets/html/strong.dart';
import 'package:rad/src/widgets/html/sub_script.dart';
import 'package:rad/src/widgets/html/super_script.dart';
import 'package:rad/src/widgets/html/table.dart';
import 'package:rad/src/widgets/html/table_body.dart';
import 'package:rad/src/widgets/html/table_column.dart';
import 'package:rad/src/widgets/html/table_column_group.dart';
import 'package:rad/src/widgets/html/table_data_cell.dart';
import 'package:rad/src/widgets/html/table_foot.dart';
import 'package:rad/src/widgets/html/table_head.dart';
import 'package:rad/src/widgets/html/table_header_cell.dart';
import 'package:rad/src/widgets/html/table_row.dart';
import 'package:rad/src/widgets/html/textarea.dart';
import 'package:rad/src/widgets/html/unordered_list.dart';

typedef abbr = Abbreviation;
typedef a = Anchor;
typedef article = Article;
typedef blockquote = Blockquote;
typedef br = BreakLine;
typedef button = Button;
typedef canvas = Canvas;
typedef caption = Caption;
typedef code = Code;
typedef div = Division;
typedef fieldset = FieldSet;
typedef footer = Footer;
typedef form = Form;
typedef header = Header;
typedef h1 = Heading1;
typedef h2 = Heading2;
typedef h3 = Heading3;
typedef h4 = Heading4;
typedef h5 = Heading5;
typedef h6 = Heading6;
typedef hr = HorizontalRule;
typedef i = Idiomatic;
typedef iframe = IFrame;
typedef img = Image;
typedef input = Input;
typedef label = Label;
typedef legend = Legend;
typedef li = ListItem;
typedef menu = Menu;
typedef nav = Navigation;
typedef option = Option;
typedef p = Paragraph;
typedef progress = Progress;
typedef select = Select;
typedef small = Small;
typedef span = Span;
typedef s = StrikeThrough;
typedef strong = Strong;
typedef sub = SubScript;
typedef sup = SuperScript;
typedef table = Table;
typedef tbody = TableBody;
typedef col = TableColumn;
typedef colgroup = TableColumnGroup;
typedef td = TableDataCell;
typedef tfoot = TableFoot;
typedef thead = TableHead;
typedef th = TableHeaderCell;
typedef tr = TableRow;
typedef textarea = TextArea;
typedef ul = UnOrderedList;

==> rad-1.0.1-rc.1.tar.gz: lib/widgets_short_html.dart <==
// ignore_for_file: directives_ordering
// ignore_for_file: camel_case_types

/// HTML widgets with short aliases.
///
library widgets_short_tags;

import 'package:rad/src/widgets/html/abbreviation.dart';
import 'package:rad/src/widgets/html/anchor.dart';
import 'package:rad/src/widgets/html/article.dart';
import 'package:rad/src/widgets/html/block_quote.dart';
import 'package:rad/src/widgets/html/break_line.dart';
import 'package:rad/src/widgets/html/button.dart';
import 'package:rad/src/widgets/html/canvas.dart';
import 'package:rad/src/widgets/html/caption.dart';
import 'package:rad/src/widgets/html/code.dart';
import 'package:rad/src/widgets/html/division.dart';
import 'package:rad/src/widgets/html/fieldset.dart';
import 'package:rad/src/widgets/html/footer.dart';
import 'package:rad/src/widgets/html/form.dart';
import 'package:rad/src/widgets/html/header.dart';
import 'package:rad/src/widgets/html/headings.dart';
import 'package:rad/src/widgets/html/horizontal_rule.dart';
import 'package:rad/src/widgets/html/idiomatic.dart';
import 'package:rad/src/widgets/html/iframe.dart';
import 'package:rad/src/widgets/html/image.dart';
import 'package:rad/src/widgets/html/input.dart';
import 'package:rad/src/widgets/html/label.dart';
import 'package:rad/src/widgets/html/legend.dart';
import 'package:rad/src/widgets/html/list_item.dart';
import 'package:rad/src/widgets/html/menu.dart';
import 'package:rad/src/widgets/html/navigation.dart';
import 'package:rad/src/widgets/html/option.dart';
import 'package:rad/src/widgets/html/paragraph.dart';
import 'package:rad/src/widgets/html/progress.dart';
import 'package:rad/src/widgets/html/select.dart';
import 'package:rad/src/widgets/html/small.dart';
import 'package:rad/src/widgets/html/span.dart';
import 'package:rad/src/widgets/html/strike_through.dart';
import 'package:rad/src/widgets/html/strong.dart';
import 'package:rad/src/widgets/html/sub_script.dart';
import 'package:rad/src/widgets/html/super_script.dart';
import 'package:rad/src/widgets/html/table.dart';
import 'package:rad/src/widgets/html/table_body.dart';
import 'package:rad/src/widgets/html/table_column.dart';
import 'package:rad/src/widgets/html/table_column_group.dart';
import 'package:rad/src/widgets/html/table_data_cell.dart';
import 'package:rad/src/widgets/html/table_foot.dart';
import 'package:rad/src/widgets/html/table_head.dart';
import 'package:rad/src/widgets/html/table_header_cell.dart';
import 'package:rad/src/widgets/html/table_row.dart';
import 'package:rad/src/widgets/html/textarea.dart';
import 'package:rad/src/widgets/html/unordered_list.dart';

typedef abbr = Abbreviation;
typedef a = Anchor;
typedef article = Article;
typedef blockquote = BlockQuote;
typedef br = BreakLine;
typedef button = Button;
typedef canvas = Canvas;
typedef caption = Caption;
typedef code = Code;
typedef div = Division;
typedef fieldset = FieldSet;
typedef footer = Footer;
typedef form = Form;
typedef header = Header;
typedef h1 = Heading1;
typedef h2 = Heading2;
typedef h3 = Heading3;
typedef h4 = Heading4;
typedef h5 = Heading5;
typedef h6 = Heading6;
typedef hr = HorizontalRule;
typedef i = Idiomatic;
typedef iframe = IFrame;
typedef img = Image;
typedef input = Input;
typedef label = Label;
typedef legend = Legend;
typedef li = ListItem;
typedef menu = Menu;
typedef nav = Navigation;
typedef option = Option;
typedef p = Paragraph;
typedef progress = Progress;
typedef select = Select;
typedef small = Small;
typedef span = Span;
typedef s = StrikeThrough;
typedef strong = Strong;
typedef sub = SubScript;
typedef sup = SuperScript;
typedef table = Table;
typedef tbody = TableBody;
typedef col = TableColumn;
typedef colgroup = TableColumnGroup;
typedef td = TableDataCell;
typedef tfoot = TableFoot;
typedef thead = TableHead;
typedef th = TableHeaderCell;
typedef tr = TableRow;
typedef textarea = TextArea;
typedef ul = UnOrderedList;
